from .marzban import Marzban, Stats, Inbound, Protocol, Network, Security, System
from . import types

__all__ = (
    "Marzban",
    "types",
    "Stats",
    "Inbound",
    "Protocol",
    "Network",
    "Security",
    "System",
)



from enum import Enum


class Flow(str, Enum):
    NONE = ""
    XTLS = "xtls-rprx-vision"


class CipherMethod(str, Enum):
    AES128 = "aes-128-gcm"
    AES256 = "aes-256-gcm"
    CHACHA20 = "chacha20-ietf-poly1305"


class DataLimitResetStrategy(str, Enum):
    NO_RESET = "no_reset"
    DAY = "day"
    WEEK = "week"
    MONTH = "month"
    YEAR = "year"


class UserStatus(str, Enum):
    ACTIVE = "active"
    DSIABLED = "disabled"
    LIMITED = "limited"
    EXPIRED = "expired"
    ON_HOLD = "on_hold"



from enum import Enum


class Security(str, Enum):
    DEFAULT = "inbound_default"
    TLS = "tls"
    NONE = "none"


class ALPN(str, Enum):
    NONE = ""
    H3 = "h3"
    H2 = "h2"
    H1 = "http/1.1"
    ALL = "h3,h2,http/1.1"
    H3H2 = "h3,h2"
    H2H1 = "h2,http/1.1"


class Fingerprint(str, Enum):
    NONE = ""
    CHROME = "chrome"
    FIREFOX = "firefox"
    SAFARI = "safari"
    IOS = "ios"
    ANDROID = "android"
    EDGE = "edge"
    F360 = "360"
    QQ = "qq"
    RANDOM = "random"
    RANDOMIZED = "randomized"
